#

    	sink filter

    	Slide 1:
    		How to install a goodest sink.

    	Step 2:
    		If you happen to find a spinning knive contraption in
    		your goodest sink, the recommendation is to:

    			1. 	Put on thick mechanic gloves, like https://amzn.to/4bKX4k6.

    			2. 	Assume that there are batteries and a completelly sentient
    				consciousness built into the spinning knife contraption.

    			3.	Try to remove any power inputs that are connected to the
    				contraption.

    			4. 	Check the instruction book or consult Youtube videos on
    				how to remove the species of spinning knife contraption
    				that you identify.

    	Step 3:
    		Install these parts.

    		Tri Clamp 1.5in Fitting:
    			https://amzn.to/3Sz1Msg

    		Tri Clamp Filter:
    			https://amzn.to/3HXT7Lb

    		2 Tri Clamp Ferrule Fittings:
    			https://amzn.to/42JZ5sk

    		EasyDrain 1½" 4-Way Cross Connector:
    			https://amzn.to/3uHUx9l

    		Sink Fitting:
    			https://amzn.to/3I0xmtV

    	Step 9.
    		Once installed, the filter might need to be
    		cleared every once in a while.